FunciSNPAnnotateSummary:
Genomic Annotation of YAFSNPs.
Description
This will annotate all identified YAFSNP for it's distance to the nearest known TSS, whether it overlapps a known exon, intron, 5'UTR, 3'UTR, promoter, lincRNA or in gene desert (intergentic) regions.
Usage
FunciSNPAnnotateSummary(snp.list)
Arguments
snp.list
a FunciSNP object: snp.list represents the FunciSNP object output from FunciSNP. See getFSNPs.
Value
data.frame with rows for each correlated SNP.
Details
All known genomic features (exon, intron, 5'UTR, 3'UTR, promoter, lincRNA or in gene desert (intergentic)) are used to annotate the newly identified YAFSNP. Information described in this data.frame is used for all summary plots, table, and bed file generations.
References
SG. Coetzee, SK. Rhie, BP. Berman, GA. Coetzee and H. Noushmehr, FunciSNP: An R/Bioconductor Tool Integrating Functional Non-coding Datasets with Genetic Association Studies to Identify Candidate Regulatory SNPs., Nucleic Acids Research, In press, 2012 (doi:10.1093/nar/gks542).